# gisus


[![image](https://img.shields.io/pypi/v/gisus.svg)](https://pypi.python.org/pypi/gisus)
[![image](https://img.shields.io/conda/vn/conda-forge/gisus.svg)](https://anaconda.org/conda-forge/gisus)


**A python package for geospatial analysis**


-   Free software: MIT License
-   Documentation: https://DBishal13.github.io/gisus
    

## Features

-   TODO
